==> tin-1.05.tar.gz: tin-1.05/tin.h <==
/*
 *  Project   : tin - a visual threaded usenet newsreader
 *  Module    : tin.h
 *  Author    : R.Skrenta / I.Lea
 *  Created   : 01-04-91
 *  Updated   : 10-10-91
 *  Release   : 1.0
 *  Notes     :
 *  Copyright : (c) Copyright 1991 by Rich Skrenta & Iain Lea
 *	            You may  freely  copy or  redistribute  this software,
 *              so  long as there is no profit made from its use, sale
 *              trade or  reproduction.  You may not change this copy-
 *              right notice, and it must be included in any copy made
 */

#include	<stdio.h>
#include	<signal.h>
#include	<pwd.h>
#include	<sys/types.h>
#include	<memory.h>
#include	<ctype.h>
#include	<time.h>
#include	<sys/stat.h>

#ifdef BSD
#	include	<strings.h>
#else
#	include	<string.h>
#	include	<malloc.h>
#endif

#ifdef SCO_UNIX
#	include	<sys/streams.h>
#	include	<sys/ptem.h>
#endif

#ifdef SIGWINCH
#	include	<sys/ioctl.h>
#	ifdef AUTO_RESIZE
#		include	<sys/ttold.h>		/* needed for resizing under an xterm */
#	endif
#endif

#include	"patchlevel.h"


#define BUG_REPORT_ADDRESS	"iain@estevax.uucp"

#ifndef SPOOLDIR
#	define		SPOOLDIR	"/usr/spool/news"
#endif
#ifndef LIBDIR
#	define		LIBDIR		"/usr/lib/news"
#endif

#define		RCDIR			".tin"
#define		RCFILE			"tinrc"
#define		INDEXDIR		".index"
#define		KILLFILE		"kill"
#define		POSTFILE		"posted"
#define		UNTHREADFILE	"unthread"

#define		DEFAULT_SHELL	"/bin/sh"
#define		DEFAULT_MAILDIR	"Mail"

#ifdef BSD
#	define		DEFAULT_EDITOR	"/usr/ucb/vi"
#	define		DEFAULT_MAILER	"/bin/rmail"
#	define		DEFAULT_MAILBOX	"/usr/spool/mail"
#	define		DEFAULT_PRINTER	"/usr/ucb/lpr"
#	define		DEFAULT_SUM		"sum"
#	ifndef USE_LONG_FILENAMES
#		define USE_LONG_FILENAMES
#	endif
#else
#	ifdef M_XENIX
#		define		DEFAULT_EDITOR	"/bin/vi"
#		define		DEFAULT_MAILBOX	"/usr/spool/mail"
#	else
#		define		DEFAULT_EDITOR	"/usr/bin/vi"
#		define		DEFAULT_MAILBOX	"/usr/mail"
#	endif
#	ifdef NCR
#		define		DEFAULT_MAILER	"/usr/bin/mailx"
#	endif
#	ifdef RS6000
#		define		DEFAULT_PRINTER	"/bin/lp"
#	endif
#	ifdef UNIXPC
#		define		DEFAULT_MAILER	"/bin/rmail"
#	endif
#	ifndef DEFAULT_MAILER
#		define		DEFAULT_MAILER	"/usr/bin/mail"
#	endif
#	ifndef DEFAULT_PRINTER
#		define		DEFAULT_PRINTER	"/usr/bin/lp"
#	endif
#	define		DEFAULT_SUM		"sum -r"
#endif

#define		DEFAULT_ACTIVE_NUM	100		/* initial size of active array */
#define		DEFAULT_ARTICLE_NUM	400		/* initial size of art array */ 
#define		DEFAULT_KILL_NUM	10		/* initial size of kill array */ 
#define		DEFAULT_SAVE_NUM	10		/* initial size of save array */ 

#define		TRUE		1
#define		FALSE		0

#define		LEN		1024

#ifdef USE_LONG_FILENAMES
#	define		LONG_PATH_PART	"part"
#	define		LONG_PATH_PATCH	"patch"
#else
#	define		LONG_PATH_PART	""
#	define		LONG_PATH_PATCH	"p"
#endif

#define		DEFAULT_COMMENT	": "	/* used when by follow-ups & replys */
#ifndef 	UNREAD_ART_MARK
#	define		UNREAD_ART_MARK	'+'		/* used to show that an art is unread */
#endif

/*
 *  used by feed.c - feed_articles()
 */
 
#define		SELECT_LEVEL			1
#define		GROUP_LEVEL				2
#define		PAGE_LEVEL				3

#define		FEED_MAIL				1
#define		FEED_PIPE				2
#define		FEED_PRINT				3
#define		FEED_SAVE				4


#ifdef USE_INVERSE_HACK
#	define		BLANK_SELECT_COLS		59
#	define		BLANK_GROUP_COLS		2
#	define		BLANK_PAGE_COLS			2
#else
#	define		BLANK_SELECT_COLS		57
#	define		BLANK_GROUP_COLS		0
#	define		BLANK_PAGE_COLS			0
#endif

#define		SCREEN_READ_UNREAD		6		/* position for "  +" / "   " */
#define		DEFAULT_COLS			132		/* used when updating indexes */
#define		INDEX_TOP				2

#define		SORT_BY_NOTHING			0		/* sort types on arts[] array */
#define		SORT_BY_SUBJ_DESCEND	1
#define		SORT_BY_SUBJ_ASCEND		2
#define		SORT_BY_FROM_DESCEND	3
#define		SORT_BY_FROM_ASCEND		4
#define		SORT_BY_DATE_DESCEND	5
#define		SORT_BY_DATE_ASCEND		6

#define		HELP_INFO				0
#define		POST_INFO				1

#define		CHECK_ANY_NEWS			0
#define		START_ANY_NEWS			1
#define		SAVE_ANY_NEWS			2

extern int sort_art_type;

extern int NOTESLINES;
extern int RIGHT_POS;
extern int MORE_POS;

extern int max_subj;
extern int max_from;

#define		TABLE_SIZE		1409
#define		MAX_PAGES		1000


#define		ESC		27
#ifdef BSD
#define		CR		'\r'
#else
#define		CR		10
#endif

/*
 * return codes for change_rcfile ()
 */

#define		NO_KILLING		0
#define		KILLING			1

/*
 *  art.thread
 */

#define		ART_NORMAL		-1
#define		ART_EXPIRED		-2

/*
 *  art.unread
 */

#define		ART_READ		0
#define		ART_UNREAD		1
#define		ART_WILL_RETURN	2

struct header {
	long artnum;
	char *subject;	/* Subject: line from mail header */
	char *from;		/* From: line from mail header */
	int thread;
	int inthread;
	int unread;		/* 0 = read, 1 = unread, 2 = will return */
	char date[16];	/* Date: line from mail header */
	char *archive;	/* Archive-name: line from mail header */
	char *part;		/* part no. of archive */
	char *patch;	/* patch no. of archive */
	int tagged;		/* 0 = not killed/tagged, 1 = killed/tagged */
};

/*
 *  header.artnum:
 *	article number in spool directory for group
 *
 *  header.thread:
 *	initially -1
 *	points to another arts[] (struct header): zero and up
 *	-2 means article has expired (wasn't found in file search
 *	of spool directory for the group)
 *
 *  header.inthread:
 *	FALSE for the first article in a thread, TRUE for all
 *	following articles in thread
 *
 *  header.read:
 *	boolean, has this article been read or not
 *
 *  header.date
 *  date: line used for sorting articles by date order
 *
 *  header.archive:
 *	archive name used in *source* groups
 *
 *  header.part:
 *	part no. of archive
 *
 *  header.patch:
 *	patch no. of archive
 *
 *  header.tagged:
 *	boolean, has this article been killed/tagged for saving or not
 */

struct group_ent {
	char *name;
	long max;
	long min;
	int next;		/* next active entry in hash chain */
	int flag;
	int read;		/* marked TRUE if group was entered during session */
	int thread;		/* marked FALSE if group is not to be threaded */
};

#define		NOTGOT			0x01	/* haven't put in my_group yet */
#define		SUBS			0x02	/* subscribed to */

/*
 *  used in hashstr.c
 */
 
struct hashnode {
	char *s;						/* the string we're saving */
	struct hashnode *next;			/* chain for spillover */
};

#define KILL_SUBJ	1
#define KILL_FROM	2
#define KILL_BOTH	3

struct kill_t {
	int kill_type;
	long kill_group;
	char *kill_subj;
	char *kill_from;
};

extern struct kill_t *killf;
extern int kill_num;
extern int max_kill;

#define POST_PROC_NONE			0
#define POST_PROC_SHAR			1
#define POST_PROC_UUDECODE		2
#define POST_PROC_UUD_LST_ZOO	3
#define POST_PROC_UUD_EXT_ZOO	4
#define POST_PROC_PATCH			5

struct save_t {
	char *subject;
	char *dir;
	char *file;
	char *archive;
	char *part;
	char *patch;
	int index;	
	int saved;	
	int is_mailbox;	
};

extern struct save_t *save;
extern int save_num;
extern int max_save;

struct screen_t {
	char *col;
};

extern struct screen_t *screen;

struct posted_t {
	char date[10];
	char group[80];
	char subj[120];
};

extern struct posted_t *posted;

#ifdef POSIX_JOB_CONTROL
extern struct sigaction art_act;
extern struct sigaction kill_act;
extern struct sigaction group_act;
extern struct sigaction main_act;
extern struct sigaction page_act;
extern struct sigaction select_act;
extern struct sigaction rcfile_act;
extern struct sigaction old_act;
#endif

#ifdef USE_NNTP
extern int can_post;	/* open.c */
#endif

extern int debug;
extern int active_num;
extern int article_num;
extern int start_line_offset;

extern int read_news_via_nntp;
extern char nntp_server[LEN];
extern int top;
extern struct header *arts;
extern long *base;
extern int max_art;

extern int index_file_killed;
extern int save_separate;
extern int save_archive_name;
extern int show_author;
extern int draw_arrow_mark;
extern int kill_articles;
extern int mark_saved_read;
extern int post_proc_type;
extern int default_printer;
extern int print_header;
extern int pos_first_unread;
extern int num_of_tagged_files;
extern int compiled_with_nntp;
extern int save_news;
extern int thread_arts;

extern char rcdir[LEN];
extern char rcfile[LEN];
extern char indexdir[LEN];
extern char killfile[LEN];
extern char postfile[LEN];

extern char msg[LEN];
extern char userid[LEN];
extern char homedir[LEN];
extern char add_addr[LEN];
extern char bug_addr[LEN];
extern char txt_help_bug_report[LEN];
extern char reply_to[LEN];
extern char my_org[LEN];
extern char active_file[LEN];
extern char newsrc[LEN];
extern char newnewsrc[LEN];
extern char delgroups[LEN];

extern char *version;
extern char cvers[LEN];
extern char progname[LEN];
extern char article[LEN];
extern char dead_article[LEN];
extern char mailer[LEN];
extern char printer[LEN];
extern char spooldir[LEN];
extern char savedir[LEN];
extern char maildir[LEN];
extern char mailbox[LEN];
extern char page_header[LEN];
extern char signature[LEN];
extern char sig[LEN];
extern char killsubj[LEN];
extern char killfrom[LEN];
extern char author_search_string[LEN];
extern char group_search_string[LEN];
extern char subject_search_string[LEN];
extern char art_search_string[LEN];
extern char default_mail_address[LEN];
extern char default_pipe_command[LEN];
extern char default_regex_pattern[LEN];
extern char default_save_file[LEN];
extern char default_shell_command[LEN];
extern char default_post_subject[LEN];
extern char proc_ch_default;				/* set in change_rcfile () */

extern char *help_select[];
extern char *help_group[];
extern char *help_page[];

extern int top_base;
extern int LINES, COLS;
extern int group_hash[TABLE_SIZE];
extern int num_active;
extern struct group_ent *active;
extern int *my_group;
extern int *unread;
extern int max_active;

extern int local_top;
extern int catchup;
extern int update;
extern int verbose;
extern int inverse_okay;

extern int tin_uid;
extern int tin_gid;
extern int real_uid;
extern int real_gid;
extern int local_index;

#ifdef SIGTSTP
extern int do_sigtstp;
#endif

#define		ctrl(c)			((c) & 0x1F)

/*
 *  Assertion verifier
 */

#ifdef __STDC__
#	define	assert(p)	if(! (p)) asfail(__FILE__, __LINE__, #p); else
#else
#	define	assert(p)	if(! (p)) asfail(__FILE__, __LINE__, "p"); else
#endif

/*
 *  function prototypes	& language definitions	
 */ 

#include	"proto.h"
#include	"lang.h"

==> tin-1.10.tar.gz: tin-1.1/tin.h <==
/*
 *  Project   : tin - a threaded Netnews reader
 *  Module    : tin.h
 *  Author    : R.Skrenta / I.Lea
 *  Created   : 01-04-91
 *  Updated   : 21-01-92
 *  Notes     : #include files, #defines & struct's
 *  Copyright : (c) Copyright 1991-92 by Rich Skrenta & Iain Lea
 *              You may  freely  copy or  redistribute  this software,
 *              so  long as there is no profit made from its use, sale
 *              trade or  reproduction.  You may not change this copy-
 *              right notice, and it must be included in any copy made
 */

#include	<stdio.h>
#include	<signal.h>
#include	<sys/types.h>
#include	<pwd.h>
#ifndef MINIX
#	include	<memory.h>
#endif
#include	<ctype.h>
#include	<time.h>
#include	<sys/stat.h>

#ifdef BSD
#	include	<strings.h>
#else
#	include	<string.h>
#	ifndef MINIX
#		include	<malloc.h>
#	else
#		include	<stdlib.h>
#	endif
#endif

#ifdef SCO_UNIX
#	include	<sys/streams.h>
#	include	<sys/ptem.h>
#endif

#ifdef M_XENIX
#	include	<prototypes.h>
#endif

#if defined(SIGWINCH) || defined(SINIX)
#	include	<sys/ioctl.h>
#	ifdef AUTO_RESIZE
#		include	<sys/ttold.h>		/* needed for resizing under an xterm */
#	endif
#endif

#if __STDC__
#	define	SIGTYPE	void
#else
#	define	SIGTYPE	int
#endif

#ifndef SPOOLDIR
#	define		SPOOLDIR	"/usr/spool/news"
#endif
#ifndef LIBDIR
#	define		LIBDIR		"/usr/lib/news"
#endif
#ifndef INEWSDIR
#	define		INEWSDIR	LIBDIR
#endif

#define		DEFAULT_SHELL	"/bin/sh"

#ifdef BSD
#	define		DEFAULT_EDITOR	"/usr/ucb/vi"
#	define		DEFAULT_MAILER	"/bin/rmail"
#	define		DEFAULT_MAILBOX	"/usr/spool/mail"
#	define		DEFAULT_PRINTER	"/usr/ucb/lpr"
#	define		DEFAULT_SUM		"sum"
#	ifndef USE_LONG_FILENAMES
#		define USE_LONG_FILENAMES
#	endif
#	define		DEFAULT_ACTIVE_NUM	1600	/* initial size of active array */
#	define		DEFAULT_ARTICLE_NUM	400		/* initial size of art array */ 
#else
#	ifdef M_XENIX
#		define		DEFAULT_EDITOR	"/bin/vi"
#		define		DEFAULT_MAILBOX	"/usr/spool/mail"
#	else
#		define		DEFAULT_EDITOR	"/usr/bin/vi"
#		define		DEFAULT_MAILBOX	"/usr/mail"
#	endif
#	ifdef NCR
#		define		DEFAULT_MAILER	"/usr/bin/mailx"
#	endif
#	ifdef RS6000
#		define		DEFAULT_PRINTER	"/bin/lp"
#	endif
#	ifdef UNIXPC
#		define		DEFAULT_MAILER	"/bin/rmail"
#	endif
#	ifdef SINIX
#		define		DEFAULT_MAILER	"/bin/rmail"
#		define		DEFAULT_PRINTER	"/bin/lpr"
#		ifndef USE_LONG_FILENAMES
#			define USE_LONG_FILENAMES
#		endif
#	endif
#	ifndef DEFAULT_MAILER
#		define		DEFAULT_MAILER	"/usr/bin/mail"
#	endif
#	ifndef DEFAULT_PRINTER
#		define		DEFAULT_PRINTER	"/usr/bin/lp"
#	endif
#	define		DEFAULT_SUM		"sum -r"
#	define		DEFAULT_ACTIVE_NUM	400		/* initial size of active array */
#	define		DEFAULT_ARTICLE_NUM	200		/* initial size of art array */ 
#endif

#ifdef USE_LONG_FILENAMES
#	define		LONG_PATH_PART	"part"
#	define		LONG_PATH_PATCH	"patch"
#else
#	define		LONG_PATH_PART	""
#	define		LONG_PATH_PATCH	"p"
#endif

#ifdef LOG_USER
#	define		LOG_USER_FILE	"/tmp/.tin_log" 
#endif

#define		DEFAULT_KILL_NUM	10		/* initial size of kill array */ 
#define		DEFAULT_SAVE_NUM	10		/* initial size of save array */ 

#define		RCDIR			".tin"
#define		RCFILE			"tinrc"
#define		INDEXDIR		".index"
#define		KILLFILE		"kill"
#define		POSTFILE		"posted"
#define		UNTHREADFILE	"unthread"
#define		DEFAULT_MAILDIR	"Mail"

/*
#define BUG_REPORT_ADDRESS	"iain@estevax.uucp"
*/
#define BUG_REPORT_ADDRESS	"iain%estevax.uucp@unido.Informatik.Uni-Dortmund.DE"

#ifdef TRUE
#	undef TRUE
#	define		TRUE		1
#else	
#	define		TRUE		1
#endif

#ifdef FALSE
#	undef FALSE
#	define		FALSE		0
#else	
#	define		FALSE		0
#endif

#define		LEN				1024
#define		MODULO_COUNT_NUM	5
#define		HEADER_LEN		1024
#define		TABLE_SIZE		1409
#define		MAX_PAGES		1000
#define		ctrl(c)			((c) & 0x1F)

#define		DEFAULT_COMMENT	": "	/* used when by follow-ups & replys */
#ifndef UNREAD_ART_MARK
#	define		UNREAD_ART_MARK	'+'		/* used to show that an art is unread */
#endif

#ifdef USE_INVERSE_HACK
#	define		BLANK_SELECT_COLS		60
#	define		BLANK_GROUP_COLS		2
#	define		BLANK_PAGE_COLS			2
#else
#	define		BLANK_SELECT_COLS		58
#	define		BLANK_GROUP_COLS		0
#	define		BLANK_PAGE_COLS			0
#endif

#define		SCREEN_READ_UNREAD		6		/* position for "  +" / "   " */
#define		DEFAULT_COLS			132		/* used when updating indexes */
#define		INDEX_TOP				2

/*
 *  used by get_arrow_key()
 */

#define		KEYMAP_UNKNOWN			0
#define		KEYMAP_UP				1
#define		KEYMAP_DOWN				2
#define		KEYMAP_PAGE_UP			3
#define		KEYMAP_PAGE_DOWN		4
#define		KEYMAP_HOME				5
#define		KEYMAP_END				6

/*
 *  used by feed.c - feed_articles()
 */
 
#define		SELECT_LEVEL			1
#define		GROUP_LEVEL				2
#define		PAGE_LEVEL				3

#define		FEED_MAIL				1
#define		FEED_PIPE				2
#define		FEED_PRINT				3
#define		FEED_SAVE				4

/*
 *  used in art.c & rcfile.c
 */
 
#define		SORT_BY_NOTHING			0		/* sort types on arts[] array */
#define		SORT_BY_SUBJ_DESCEND	1
#define		SORT_BY_SUBJ_ASCEND		2
#define		SORT_BY_FROM_DESCEND	3
#define		SORT_BY_FROM_ASCEND		4
#define		SORT_BY_DATE_DESCEND	5
#define		SORT_BY_DATE_ASCEND		6

#define		SHOW_FROM_NONE			0
#define		SHOW_FROM_ADDR			1
#define		SHOW_FROM_NAME			2
#define		SHOW_FROM_BOTH			3

/*
 *  used in help.c
 */

#define		HELP_INFO				0
#define		POST_INFO				1

/*
 *  used in save.c
 */

#define		CHECK_ANY_NEWS			0
#define		START_ANY_NEWS			1
#define		MAIL_ANY_NEWS			2
#define		SAVE_ANY_NEWS			3

/*
 *  used in help.c
 */

#define		HEADER_TO				0
#define		HEADER_SUBJECT			1

/*
 *  used in page.c & post.c
 */

#define		POSTED_NONE			0
#define		POSTED_REDRAW			1
#define		POSTED_OK			2

/*
 *  Assertion verifier
 */

#if __STDC__
#	define	assert(p)	if(! (p)) asfail(__FILE__, __LINE__, #p); else
#else
#	define	assert(p)	if(! (p)) asfail(__FILE__, __LINE__, "p"); else
#endif

#define		ESC		27
#if defined(BSD) || defined(MINIX)
#	define		CR		'\r'
#else
#	define		CR		10
#endif

/*
 * return codes for change_rcfile ()
 */

#define		NO_KILLING		0
#define		KILLING			1

/*
 *  art.thread
 */

#define		ART_NORMAL		-1
#define		ART_EXPIRED		-2

/*
 *  art.unread
 */

#define		ART_READ		0
#define		ART_UNREAD		1
#define		ART_WILL_RETURN	2

/*
 * used by group_t & my_group[]
 */
 
#define		UNSUBSCRIBED	0x01	/* haven't put in my_group[] yet */
#define		SUBSCRIBED		0x02	/* subscribed to */

/*
 * kill_type used in struct kill_t
 */
 
#define KILL_SUBJ	1
#define KILL_FROM	2
#define KILL_BOTH	3

/*
 * used in feed.c & save.c
 */
 
#define POST_PROC_NONE			0
#define POST_PROC_SHAR			1
#define POST_PROC_UUDECODE		2
#define POST_PROC_UUD_LST_ZOO	3
#define POST_PROC_UUD_EXT_ZOO	4

/*
 *  struct article_t - article header
 *
 *  article.artnum:
 *	article number in spool directory for group
 *
 *  article.thread:
 *	initially -1
 *	points to another arts[] (struct article_t): zero and up
 *	-2 means article has expired (wasn't found in file search
 *	of spool directory for the group)
 *
 *  article.inthread:
 *	FALSE for the first article in a thread, TRUE for all
 *	following articles in thread
 *
 *  article.unread:
 *	boolean, has this article been read or not
 *
 *  article.date
 *  date: line used for sorting articles by date order
 *
 *  article.archive:
 *	archive name used in *source* groups
 *
 *  article.part:
 *	part no. of archive
 *
 *  article.patch:
 *	patch no. of archive
 *
 *  article.killed:
 *	boolean, has this article been killed
 *
 *  article.tagged:
 *	boolean, has this article been tagged for saving or not
 */

struct article_t {
	long artnum;
	char *subject;	/* Subject: line from mail header */
	char *from;		/* From: line from mail header (address) */
	char *name;		/* From: line from mail header (full name) */
	int thread;
	int inthread;
	int unread;		/* 0 = read, 1 = unread, 2 = will return */
	char date[16];	/* Date: line from mail header */
	char *archive;	/* Archive-name: line from mail header */
	char *part;		/* part no. of archive */
	char *patch;	/* patch no. of archive */
	int killed;		/* 0 = not killed, 1 = killed */
	int tagged;		/* 0 = not tagged, 1 = tagged */
};

/*
 *  struct group_t - newsgroup info from active file
 */

struct group_t {
	char *name;
	long max;
	long min;
	char moderated;
	int next;		/* next active entry in hash chain */
	int flag;
	int read;		/* marked TRUE if group was entered during session */
	int thread;		/* marked FALSE if group is not to be threaded */
};

/*
 *  used in hashstr.c
 */
 
struct hashnode {
	char *s;						/* the string we're saving */
	struct hashnode *next;			/* chain for spillover */
};

/*
 *  used in kill.c
 */
 
struct kill_t {
	int kill_type;
	long kill_group;
	char *kill_subj;
	char *kill_from;
};

struct save_t {
	char *subject;
	char *dir;
	char *file;
	char *archive;
	char *part;
	char *patch;
	int index;	
	int saved;	
	int is_mailbox;	
};

struct screen_t {
	char *col;
};

struct posted_t {
	char date[10];
	char group[80];
	char subj[120];
};

/*
 *  function prototypes	& extern definitions	
 */ 

#include	"patchlev.h"
#include	"extern.h"
#include	"proto.h"
